import logging

from odoo import models

from odoo.addons.saas_worker.util import version_gte


_logger = logging.getLogger(__name__)


class ResCompany(models.Model):
    _inherit = 'res.company'

    def write(self, values):
        # Reset the connected account of Stripe providers whose company's main currency is changed.
        if 'currency_id' in values:
            currency_changed_companies = self.filtered(
                lambda comp: comp.currency_id.id != values['currency_id']
            )
            if currency_changed_companies:
                if version_gte('16.0'):
                    PaymentProvider = self.env['payment.provider']
                else:
                    PaymentProvider = self.env['payment.acquirer']
                linked_connected_providers = PaymentProvider.search([
                    ('company_id', 'in', currency_changed_companies.ids),
                    ('stripe_account_id', '!=', False),
                ])
                for provider in linked_connected_providers:
                    _logger.warning(
                        "Resetting connected account with id %(account_id)s of provider with id "
                        "%(provider_id)s because the company's main currency was updated.",
                        {'account_id': provider.stripe_account_id, 'provider_id': provider.id},
                    )
                    provider.action_stripe_reset_connected_account()

        return super().write(values)
